@@ -1,6 +1,6 @@
-# $Id: Xango.pm 67 2005-06-09 10:30:55Z daisuke $
+# $Id: Xango.pm 91 2005-10-17 13:36:28Z daisuke $
 #
-# Daisuke Maki <dmaki@cpan.org>
+# Copyright (c) 2005 Daisuke Maki <dmaki@cpan.org>
 # All rights reserved.
 
 package Xango;
@@ -13,15 +13,19 @@ use POSIX();
 
 BEGIN
 {
-    $VERSION = '0.08';
+    $VERSION = '1.00';
 
+    my $default_from_env = sub {
+        my($var, $default) = @_;
+        my $env_var = 'XANGO_' . $var;
+        return exists $ENV{$env_var} ? $ENV{$env_var} : $default;
+    };
     # Define symbols. If users define them before Xango.pm is loaded,
     # then we respect their values.
-    my %constants = (
-        DEBUG => 0
-    );
+    my %constants = map { ($_ => $default_from_env->($_, 0)) } qw(DEBUG);
+
     while (my($const, $value) = each %constants) {
-        if (!UNIVERSAL::can(__PACKAGE__, $const)) {
+        if (! __PACKAGE__->can($const)) {
             eval "sub $const { '$value' }";
             die if $@;
         }
@@ -81,9 +85,14 @@ Xango - Event Based High Performance Web Crawler Framework
 
 =head1 DESCRIPTION
 
-Xango is a frameworlk for writing web crawlers. As such, it doesn't do
+  ******************  WARNING! WARNING! WARNING! ****************
+  * This new release is NOT compatible with the old Xango 0.0x! *
+  * Beware and use at your own risk.                            *
+  ***************************************************************
+
+Xango is a framework for writing web crawlers. As such, it doesn't do
 a whole lot by itself - you need to create custom handlers to do the
-grunt work. See the documentation for L<Xango::Broker|Xango::Broker>
+grunt work. See the documentation for L<Xango::Manual::Intro|Xango::Manual::Intro>
 for more details on how to write your own crawler.
 
 Please note that Xango is still in beta. Some behavior may change as we
@@ -103,6 +112,39 @@ of the logic. See L<Xango::Broker|Xango::Broker> for details
 The Handler is the component in which the Broker delegates the above
 processing to.
 
+=head1 CONSTANTS
+
+There are a few constants that may change the behavior of Xango. You can
+either set these by pre-declaring the constant subroutine of the same name
+or you can set them by populating the corresponding environment variable,
+which is prefixed with 'XANGO_'
+
+For example,
+
+  BEGIN { sub Xango::DEBUG { 1 } }
+  use Xango;
+
+or 
+
+  $ENV{XANGO_DEBUG} = 1;
+  use Xango;
+
+will both toggle the DEBUG switch.
+
+See blow for the list of possible flags and switches.
+
+=head2 DEBUG
+
+Set this to 1 if you want to enable debugging messages. 
+
+=head1 FUNCTIONS
+
+=head2 debug
+
+=head2 info
+
+These are simple interface to the underlying logging mechanism
+
 =head1 DEBUGGING
 
 To turn debugging on, you need to pre-declare some constants (which, in Perl,
@@ -130,10 +172,17 @@ work, including a tutorial.
 
 =back
 
+=head1 CAVEATS
+
+This is an alpha version release. Expect a lot of things to be still either
+in broken or experimental stage.
+
 =head1 SEE ALSO
 
 L<POE|POE>
-L<Xango::Broker|Xango::Broker>
+L<Xango::Manual::Intro>
+L<Xango::Broker::Pull>
+L<Xango::Broker::Push>
 
 =head1 AUTHOR
 
